
//  Created by Tencent on 2023/06/09.
//  Copyright © 2023 Tencent. All rights reserved.
/**
 *
 *  1. This file declares the TDeskVideoItem class, TDeskSnapshotItem class, and TDeskVideoMessageCellData class.
 *    - TDeskVideoItem corresponds to V2TIMVideoElem in the IM SDK. We convert the classes in the SDK to TDeskVideoItem, which is convenient for us to further
 * process and operate the data.
 *    - TDeskSnapshotItem corresponds to the video cover class in the IM SDK. It is still an image in essence, but is bound to the corresponding Video.
 *    - TDeskVideoMessageCellData inherits from the TDeskMessageCellData class and is used to store a series of data and information required by the image message
 * unit.
 *  2. The business logic for obtaining video information and cover information has been implemented in this document. When you need to get video and cover
 * data, you can directly call the relevant member functions declared in this file
 */

#import <TDeskCommon/TDesk_TUIBubbleMessageCellData.h>
#import "TDesk_TUIChatDefine.h"
#import "TDesk_TUIMessageItem.h"

NS_ASSUME_NONNULL_BEGIN

/////////////////////////////////////////////////////////////////////////////////
//
//                            TDeskVideoMessageCellData
//
/////////////////////////////////////////////////////////////////////////////////

@interface TDeskVideoMessageCellData : TDeskBubbleMessageCellData <TDeskMessageCellDataFileUploadProtocol>

@property(nonatomic, strong) UIImage *thumbImage;
@property(nonatomic, strong) NSString *videoPath;
@property(nonatomic, strong) NSString *snapshotPath;
@property(nonatomic, strong) TDeskVideoItem *videoItem;
@property(nonatomic, strong) TDeskSnapshotItem *snapshotItem;
@property(nonatomic, assign) NSUInteger uploadProgress;
@property(nonatomic, assign) NSUInteger thumbProgress;
@property(nonatomic, assign) NSUInteger videoProgress;
/// Is the current message a custom message
@property(nonatomic, assign) BOOL isPlaceHolderCellData;

+ (TDeskMessageCellData *)placeholderCellDataWithSnapshotUrl:(NSString *)snapshotUrl thubImage:(UIImage *)thubImage;

- (void)getVideoUrl:(void (^)(NSString *url))urlCallBack;

/**
 *  Downloading the cover image of the video. It will download from server if the image not exist in local.
 */
- (void)downloadThumb;
- (void)downloadThumb:(TUIVideoMessageDownloadCallback)finish;

/**
 *  Downloading the video file. It will download from server if the video not exist  in local.
 */
- (void)downloadVideo;

- (BOOL)isVideoExist;

@end

NS_ASSUME_NONNULL_END
